Vincent
=======

.. image:: http://farm9.staticflickr.com/8521/8644902478_0d1513db92_o.jpg
    :alt: Vincent

A Python to Vega translator
^^^^^^^^^^^^^^^^^^^^^^^^^^^

The folks at Trifacta are making it easy to build visualizations on top
of D3 with Vega. Vincent makes it easy to build Vega with Python.

Concept
-------

The data capabilities of Python. The visualization capabilities of
JavaScript.

Vincent takes Python data structures (tuples, lists, dicts, and Pandas
DataFrames) and translates them into
`Vega <https://github.com/trifacta/vega>`__ visualization grammar. It
allows for quick iteration of visualization designs via simple addition
and subtraction of grammar elements, and outputs the final visualization
to JSON.

